#[non_exhaustive]pub enum AdminState {
Up,
Down,
Unknown,
}Expand description
The administrative state of an interface, as configured by the operator.
Distinct from OperationalState: an interface can be administratively
up but operationally down (cable unplugged), or administratively down
(and therefore always operationally down).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Up
Down
Unknown
The platform does not expose a separate administrative state (e.g. BSD/macOS route-socket interfaces report a single combined state).