#[non_exhaustive]pub enum OperationalState {
Up,
Down,
NoCarrier,
Unknown,
}Expand description
The operational state of an interface, as observed from the link layer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Up
Down
NoCarrier
The interface is up but has no carrier / lower-layer connectivity.
Unknown
The platform does not expose a separate operational state.